#!/bin/csh -f
#
# build-samples.csh: build the S2PLOT sample FORTRAN and C programs
#
# David Barnes, November 2005
#
# $Id: build-functions.csh,v 1.2 2007/04/04 23:07:40 dbarnes Exp $

if (!(${?S2PATH})) then
  echo "S2PATH environment variable MUST be set ... please fix and retry."
  exit(-1);
endif
if (! -d $S2PATH || ! -e ${S2PATH}/s2plot.csh) then
  echo "S2PATH is set but invalid: ${S2PATH} ... please fix and retry."
  exit(-1);
endif
source ${S2PATH}/s2plot.csh
if ($status) then
  exit(-1)
endif

set thisdir=$cwd
if ($thisdir != $S2PATH) then
  echo "You must be in directory ${S2PATH} to run build-samples.csh script."
  echo "(or if you are, try removing any trailing '/' in your S2PATH setting)"
  exit(-1);
endif

if ($S2SHARED == yes) then
  echo "Using shared S2PLOT library for ${S2KERNEL}."
else
  echo "Using static S2PLOT library for ${S2KERNEL}."
endif

if (! -d $S2KERNEL) then
  echo "Directory ${S2KERNEL} does not exist!  Cannot build!  Try running"
  echo "build-lib.csh script first, or re-installing your distribution."
  exit(-1);
endif

if (! -e ${S2KERNEL}/${S2LIBNAME}) then
  echo "Library ${S2LIBNAME} is missing!  Cannot build!  Try running "
  echo "build-lib.csh script first, or re-installing your distribution."
  exit(-1);
endif

echo "Entering target directory ${S2KERNEL}."
cd $S2KERNEL

set S2OBJECTS=""

foreach targetext (`cd ../functions && ls *.c`)
  set target=`echo $targetext | sed -e 's/\.c//g'`
  echo "Compiling function demonstration program ($target) ..."
  $S2COMPILER ../functions/${target}.c
  set S2OBJECTS="${S2OBJECTS} ${target}.o"
  echo "Linking function demonstration program (${target}) ..."
if ($S2OSTYPE != cygwin) then
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} -L${S2X11PATH}/lib -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}
else
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${GLLINKS} ${IMATH} -lm
endif
  if ($S2KERNEL == darwin && $S2SHARED == yes) then
    echo "Modifying dynamic library path ..."
    install_name_tool -change ${S2PATH}/${S2KERNEL}/${S2LIBNAME} @executable_path/${S2LIBNAME} ${target}
  endif
end

echo Removing objects ...
rm -rf $S2OBJECTS

echo Done!


