#!/bin/csh -f
#
# cbuild.csh: compile and link 'simple' C S2PLOT program
#
# David Barnes, November 2005
#
# $Id: cbuild.csh,v 3.7 2007/04/04 23:07:40 dbarnes Exp $
#
# usage: cbuild.csh target
# - compiles 'target.c' and links to produce executable 'target'

if (!(${?S2PATH})) then
  echo "S2PATH environment variable MUST be set ... please fix and retry."
  exit(-1);
endif
if (! -d $S2PATH || ! -e ${S2PATH}/s2plot.csh) then
  echo "S2PATH is set but invalid: ${S2PATH} ... please fix and retry."
  exit(-1);
endif
source ${S2PATH}/s2plot.csh
if ($status) then
  exit(-1)
endif

set thisdir=$cwd
if ($thisdir == $S2PATH) then
  echo "You must NOT be in directory ${S2PATH} to build your own programs."
  exit(-1);
endif

set target=$1
set source=${target}.c
set object=${target}.o
if (! -e ${source}) then
  echo "Cannot find source code: ${source}."
  exit(-1);
endif 

echo "Compiling source code file ${source} ..."
echo $S2COMPILER -I${S2PATH} $source
$S2COMPILER -I${S2PATH} $source

echo "Linking object file ${target}.o ..."
$S2CLINKER -o $target ${object} -L${S2PATH}/${S2KERNEL} ${S2LINKS} ${MLLINKS} ${GLLINKS} -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}

echo "Cleaning up ..."
rm -rf $object

echo "Done!"
