c fs2uc2.f: demonstration / use case 2 for S2PLOT library.
c
c David Barnes, November 2005
c
c $Id: fs2uc2.f,v 3.1.1.1 2006/12/22 03:33:25 dbarnes Exp $
c
c Demonstrates multiple plots via viewport settings, coordinate
c labelling, surfaces and flat plots, and parametric functions,
c from a FORTRAN driver program.
c
      INCLUDE 'fs2uc2.inc'
c
c     Functions to be used by S2PLOT functions like s2funt, s2funxy, etc.
c     MUST be externally defined for FORTRAN compilations.
      EXTERNAL FFUNCX, FFUNCY, FFUNCZ
c     
c     Some parameters
      INTEGER NXI, NYI
      PARAMETER (NXI=64, NYI=64)
c     
c     Some useful variables
      REAL IMAGE(NXI,NYI)
      REAL TR(8), TRA(12)
      REAL MINZ,MAXZ,R
      INTEGER I, J
      REAL X1, X2, Y1, Y2, Z1, Z2
c     
c     Set the bounds we will use in S2PLOT
      X1 = -XLIMIT
      X2 =  XLIMIT
      Y1 = -YLIMIT
      Y2 =  YLIMIT
      Z1 = -ZLIMIT/4.0
      Z2 =  ZLIMIT
c     
c     Fill in the data arrays with points and errors
      MINZ = 9E30
      MAXZ = -9E30
      DO 20 I=1,NXI
         DO 30 J=1,NYI
            R = 1. * (I-NXI/2)*(I-NXI/2) / (NXI*NXI) + 
     +           1. * (J-NYI/2)*(J-NYI/2) / (NYI*NYI)
            R = 9.5 * SQRT(R)
            IF (R.GT.0) THEN
               IMAGE(I,J) = 2.5 * SIN(R)/R
            ELSE
               IMAGE(I,J) = 2.5
            ENDIF
            R = 1. * (I-NXI/4)*(I-NXI/4) / (NXI*NXI*0.04) + 
     +           (J-NYI/3)*(J-NYI/3) / (NYI*NYI*0.04)
            R = 0.5 * R
            if (R.GT.0) THEN
               IMAGE(I,J) = IMAGE(I,J) - 1.5 * SIN(R)/R
            ELSE
               IMAGE(I,J) = IMAGE(I,J) - 1.5
            ENDIF
            IF (IMAGE(I,J).LT.MINZ) THEN
               MINZ = IMAGE(I,J)
            ENDIF
            IF (IMAGE(I,J).GT.MAXZ) THEN
               MAXZ = IMAGE(I,J)
            ENDIF
 30      CONTINUE
 20   CONTINUE
c     
c     
c     Set up a basic transformation matrix 
      TR(1) = X1
      TR(2) = (X2-X1) / (NXI-1)
      TR(3) = 0.0
      TR(4) = Y1
      TR(5) = 0.0
      TR(6) = (Y2-Y1) / (NYI-1)
      TR(7) = Z1 - MINZ * (Z2-Z1) / (MAXZ-MINZ)
      TR(8) = (Z2-Z1) / (MAXZ-MINZ)
c     
c     
c     Open the S2PLOT device, in fullscreen, passive stereo mode
      call s2open(1, 2)
c     
c     Set viewport
      call s2svp(-1.,0.,-1.,0.,-2.,0.)
c     Set the S2PLOT world coordinate range
      call s2swin(X1, X2, Y1, Y2, Z1, Z2)
c     
c     install a nice colormap
      call s2icm("astro", 1000, 1400)
      call s2scir(1000, 1400)
c     
c     Plot the surface!
      call s2surp(IMAGE, NXI, NYI, 0, NXI-1, 0, NYI-1, MINZ, MAXZ, TR)
c     
c     plot the same data again, but on the base-level z plane, using the
c     more general s2surpa function, using a new colormap too.
c     
      TRA(1) = TR(1)
      TRA(2) = TR(2)
      TRA(3) = TR(3)
      TRA(4) = 0.0
c     
      TRA(5) = TR(4)
      TRA(6) = TR(5)
      TRA(7) = TR(6)
      TRA(8) = 0.0
c     
      TRA(9) = 0.0
      TRA(10) = 0.0
      TRA(11) = 0.0
      TRA(12) = 0.0
c     
      call s2icm("rainbow", 2000, 3000)
      call s2scir(2000, 3000)
      call s2surpa(image, NXI, NYI, 0, NXI-1, 0, NYI-1, MINZ, MAXZ, 
     +     TRA)
      
c     Ask S2PLOT to draw and label a box around the "world"
      call s2sci(3)
      call s2sch(1.2)
      call s2slw(1.)
      call s2box('ABCDETSMNG', 0., 0, 'ABCDETSMNG', 0., 0, 
     +     'ABCDETSMNG', 0., 0)
c     
c     
c     change viewport, ie. draw another plot somewhere else.
      call s2svp(0.5, 1.5, 0.5, 1.5, 0.5, 1.5)
c     plot a parametric line
      call s2slw(3.)
      call s2sci(7)
      call s2funt(FFUNCX, FFUNCY, FFUNCZ, 1000, -TWOPI, TWOPI)
      call s2slw(1.)
      call s2sci(4)
      call s2box('ABCDETSMNG', 0., 0, 'ABCDETSMNG', 0., 0, 
     +     'ABCDETSMNG', 0., 0)
c     
c     Go into S2PLOT interactive mode
      call s2show(1)
c     
      end
