! fs2uc3.f90: demonstration / use case 3 for S2PLOT library.
!
! David Barnes, February 2006
!
! $Id: fs2uc3.f90,v 3.2 2007/04/04 23:07:00 dbarnes Exp $
!
! Demonstrates drawing coordinate box, plotting coloured parametric
! functinos, various point symbols, and disks, circles and arrows,
! drawn in different colours and thicknesses, from a FORTRAN driver
! program.
!
      INCLUDE 'fs2uc3.inc'
!     
!     Functions to be used by S2PLOT functions like s2funtc etc., MUST
!     be externally defined for FORTRAN compilations.
      EXTERNAL FFX, FFY, FFZ, FFC
!     
!     Some useful variables
      REAL X1, X2, Y1, Y2, Z1, Z2
      REAL*8 PXYZ(3)
      REAL*8 NXYZ(3)
      REAL*8 COLOUR(3)
!     
!     Set the bounds we will use in S2PLOT
      X1 = -XLIMIT
      X2 =  XLIMIT
      Y1 = -YLIMIT
      Y2 =  YLIMIT
      Z1 = -ZLIMIT
      Z2 =  ZLIMIT
!     
!     Open the S2PLOT device, in mono and non-fullscreen mode
      call s2open(0, 0)
!     
!     Set the background and standard colours
      call ss2sbc(1., 1., 1.)
      call s2scr(0, 1., 1., 1.)
      call s2scr(1, 0., 0., 0.)
!
!     Set the S2PLOT world coordinate range
      call s2swin(X1, X2, Y1, Y2, Z1, Z2)
!     
!     Draw and label a box around the points in cyan colour
      call s2sci(5)
      call s2sch(1.2)
      call s2slw(1.0)
      call s2box('BCDETS', 0., 0, 'BCDETS', 0., 0, 'BCDETS', 0., 0)
!     
!     Plot a parametrically-defined line using colour according to a colormap
      call s2slw(3.0)
      call s2icm('rainbow', 3000, 3600)
      call s2scir(3000, 3600)
      call s2funtc(FFX, FFY, FFZ, FFC, 1000, -TWOPI, TWOPI)
      call s2slw(1.0)
!     
!     Plot some points and symbols
      X1 = XLIMIT * 0.5
      Y1 = YLIMIT * 0.5
      Z1 = ZLIMIT * 0.5
!     dot
      call s2sci(1)
      call s2pt(1, X1, Y1, Z1, 1)
!     3d cross
      X1 = -X1
      call s2sci(4)
      call s2pt(1, X1, Y1, Z1, 2)
!     sphere
      Y1 = -Y1
      call s2sci(3)
      call s2pt(1, X1, Y1, Z1, 4)
!     shaded box
      Z1 = -Z1
      call s2sci(8)
      call s2pt(1, X1, Y1, Z1, 6)
!     wireframe box
      X1 = -X1
      call s2sci(7)
      call s2pt(1, X1, Y1, Z1, 0)
!     
!     Try drawing some arrows...
      call s2sci(5)
      X1 = -1.0
      Y1 = -1.0
      Z1 = -1.0
      X2 = 1.0
      Y2 = 1.0
      Z2 = 1.0
      call s2arro(X1, Y1, Z1, X2, Y2, Z2)
      call s2sci(2)
      Z2 = 24.0
      X1 = -3.0
      Y1 = 8.0
      Y2 = -6.7
      call s2slw(3.)
      call s2sch(2.4)
      call s2sah(1, 60.0, 0.8)
      call s2arro(X1, Y1, Z1, X2, Y2, Z2)
!     
!     Try a few disks
      call s2sci(1)
      call s2diskxy(0., 0., 0., 1., 3.)
      call s2sci(15)
      call s2diskxz(0., 0., 0., 0., 0.7)
      call s2sci(4)
      call s2diskyz(0., 5., 3., 2.9, 3.0)
!     
!     and now some circles
      call s2slw(2.0)
      call s2sci(2)
      call s2circxy(0., 0., 0., 3.0, 40, -1.)
      call s2sci(3)
      call s2circxz(5., 5., 5., 6., 62, 1.)
      call s2sci(7)
      call s2circyz(-3., -3., 0., 1.4, 6, 2.5)
!
!     now a textured sphere !!!
      call ss2ssr(32)
      call ns2spheret(-5., -18., -3., 5., 1., 0., 0., &
           'firetile2_pow2_rgb.tga')
!
!     now an "arbitrarily oriented" disk, coloured as I like */
      call ns2disk(5., 18., 6., -1., -1., -1., 1., 3., 0.8, 0.4, 0.2)
      PXYZ(1) = 5.
      PXYZ(2) = 18.
      PXYZ(3) = 6.
      NXYZ(1) = -1.
      NXYZ(2) = 1.
      NXYZ(3) = 0.5
      COLOUR(1) = 0.4
      COLOUR(2) = 0.2
      COLOUR(3) = 0.8
      call ns2vdisk(PXYZ, NXYZ, 0., 2., COLOUR)
!
!     Go into S2PLOT interactive mode
      call s2show(1)
!     
      end
