! fs2uc4.f90: demonstration / use case 4 for S2PLOT library.
!
! David Barnes, February 2006
!
! $Id: fs2uc4.f90,v 3.1 2006/12/22 03:33:25 dbarnes Exp $
!
! Demonstrates logarithmic and exponential/decimal labelling options, 
! and 3-d vector field plotting, from a FORTRAN driver program.
!
!     Parameters
      REAL XLIMIT, YLIMIT, ZLIMIT, TWOPI
      PARAMETER (XLIMIT=2.2, YLIMIT=3.4, ZLIMIT=1.6)
      PARAMETER (TWOPI=6.2831853)
      INTEGER NXI, NYI, NZI
      PARAMETER (NXI=10, NYI=10, NZI=15)
!     
!     Some useful variables
      REAL X1, X2, Y1, Y2, Z1, Z2
      REAL A(NXI,NYI,NZI), B(NXI,NYI,NZI), C(NXI,NYI,NZI)
      REAL TR(12)
      REAL X, Y, Z
      REAL MINLENGTH, MAXLENGTH
      INTEGER I, J, K
!     
!     Set the bounds we will use in S2PLOT
      X1 = -XLIMIT
      X2 =  XLIMIT 
      Y1 = -YLIMIT
      Y2 =  YLIMIT
      Z1 = ZLIMIT+4.
      Z2 = 3.*ZLIMIT+4.
!
!     Construct a vector field with components A, B, C.
      MINLENGTH = 9e30
      MAXLENGTH = -9e30
      DO 20 I=1,NXI
         X = 1. * I / (NXI-1.) * TWOPI
         DO 19 J=1,NYI
            Y = 1. * J / (NYI-1.) * 2. * TWOPI
            DO 18 K=1,NZI
               Z = 1. * K / (NZI-1.) * 4. * TWOPI
               A(I,J,K) = SIN(X) + COS(Y) * Z / 14.
               B(I,J,K) = COS(X) - SIN(Y) * Z / 13.
               C(I,J,K) = 0.5 + SIN(X) * COS(Y)
               LENGTH = SQRT(A(I,J,K)**2 + B(I,J,K)**2 + C(I,J,K)**2)
               IF (LENGTH > MAXLENGTH) THEN
                  MAXLENGTH = LENGTH
               ENDIF
               IF (LENGTH < MINLENGTH) THEN
                  MINLENGTH = LENGTH
               ENDIF
 18         CONTINUE
 19      CONTINUE
 20   CONTINUE
!     
!     Construct the "unity" transformation matrix
      TR(1) = X1
      TR(2) = (X2-X1)/(NXI-1.)
      TR(3) = 0.
      TR(4) = 0.
      
      TR(5) = Y1
      TR(6) = 0.
      TR(7) = (Y2-Y1)/(NYI-1.)
      TR(8) = 0.
      
      TR(9) = Z1
      TR(10) = 0.
      TR(11) = 0.
      TR(12) = (Z2-Z1)/(NZI-1.)
!     
!     Open the S2PLOT device, in mono and non-fullscreen mode
      call s2open(0, 2)
!     
!     Set the S2PLOT world coordinate range
      call s2svp(-0.5, 0.5, -0.5, 0.5, -0.5, 0.5)
      call s2swin(x1, x2, y1, y2, z1, z2);
!     
!     Install a nice colormap
      call s2icm('gray', 1000, 1400)
      call s2scir(1000, 1400)
!     
!     Plot the vector field
      call s2sah(1, 30., 0.4)
      call s2vect3(A, B, C, NXI, NYI, NZI, 0, NXI-1, 0, NYI-1, &
           0, NZI-1, 0.3, 0, TR, -1., 1, MINLENGTH, MAXLENGTH)
      
!     Ask S2PLOT to draw and label a box around the "world"
      call s2sci(2)
      call s2sch(1.2)
      call s2slw(1.)
      call s2box('BCDETSGMNL', 0., 0, 'BCDETSGMN', 0., 0, &
           'BCDETSGMNL2', 0., 0)
!     
!     Go into S2PLOT interactive mode
      call s2show(1)
!     
      end
