! fs2uc6.f90: demonstration / use case 6 for S2PLOT library.
!
! David Barnes, February 2006
!
! $Id: fs2uc6.f90,v 3.2 2007/04/04 22:56:39 dbarnes Exp $
!
! Demonstrates coloured surface plot, wedge and plot annotation,
! text drawing functions and how to create "double-sided" labels,
! and introduces basic dynamic geometry in the form of a bouncing
! ball and randomly-walking dots.  Also demonstrates the PGPlot-
! inspired string interface to choose the device via user prompt
! and/or environment variable.  All from a FORTRAN driver program.
!
! NOTE: this file contains the "main program" for fs2uc7.  The next to 
! last thing the program does is to register a callback function with 
! the S2PLOT library.  This callback function (like all S2PLOT callback
! functions used from FORTRAN) *must* be external to this source file,
! and is declared so in the initial block of code just below.  The 
! source code for the 'NEWCALLBACK' function resides separately in a 
! second source file.  Similarly, the function 'FXY' must be external,
! and in this case is also defined in the second source file.
!
      INCLUDE 'fs2uc6.inc'
!     
!     Functions to be used by S2PLOT functions like s2funtc etc., MUST
!     be externally defined for FORTRAN compilations.
      EXTERNAL NEWCALLBACK,FUNCXY,NUMCB
!
!     Common block to share "number" variable between main and fns
      INCLUDE 'fs2uc6b.inc'
!     Some variables
      REAL X1,X2,Y1,Y2,Z1,Z2
      REAL DMIN,DMAX
      REAL HOVER
      PARAMETER (HOVER=0.02)
      CHARACTER XYLAB*14,XZLAB*19,YZLAB*13
      PARAMETER (XYLAB='XY Label qg YX',XZLAB='XZ label goes here!')
      PARAMETER (YZLAB='Put it there.')
!
!     Open the S2PLOT device, in mono and fullscreen mode
      call s2opend('/?')
!      call s2env(-XLIMIT,XLIMIT,-YLIMIT,YLIMIT,-1.,1., 0, 0)
!
!     Install a very nice colormap
      call s2icm('iron', 1000, 1400)
      call s2scir(1000, 1400)
!     
!     plot the function, because ctl=1, s2funxy will auto scale and 
!     label the plot for us :-)
      call s2sci(6)
      call s2funxy(FUNCXY, 20, 20, -XLIMIT, XLIMIT, -YLIMIT, YLIMIT, 1)
      call s2sci(1)
      call s2lab('x', 'y', 'f(x,y)', 's2funxy used to plot a surface')
      call s2iden('\nExtra info here, and on ...\n ... the next line!')
!
!     find out coordinate system settings
      call s2qwin(X1,X2,Y1,Y2,Z1,Z2)
      DMIN=Z1
      DMAX=Z2
!
!     ... and draw a wedge ...
      call s2wedge('Jy', 0.03, 0.06, 0.03, 0.41, DMIN, DMAX, 2)
!
!     Now try some text labels of our own
      call s2sch(3.5)
!     obtain padded bounding box of the proposed xy label and draw a rect
      call s2qtxtxy(X1, X2, Y1, Y2, 0., 0., 1., XYLAB, 0.2)
      call s2sci(14)
      call s2rectxy(X1, X2, Y1, Y2, 1.)
!     change color and draw label
      call s2sci(7)
      call s2textxy(0., 0., 1. + HOVER, XYLAB)
!     and here's how to draw on the back of the rectangle
!     (use zero pad to find starting point)
      call s2qtxtxy(X1, X2, Y1, Y2, 0., 0., 1., XYLAB, 0.)
      call s2textxyf(X2, 0., 1. - HOVER, -1., 1., XYLAB)
!
!     flip the XZ label for fun
      call s2sch(5.)
      call s2qtxtxzf(X1, X2, Z1, Z2, 0., 25., 0., -1., 1., XZLAB, 0.2)
      call s2sci(14)
      call s2rectxz(X1, X2, Z1, Z2, 25.)
      call s2sci(5)
      call s2textxzf(0., 25.+HOVER*10., 0., -1., 1., XZLAB)
      call s2qtxtxzf(X1, X2, Z1, Z2, 0., 25., 0., -1., 1., XZLAB, 0.)
      call s2textxzf(X2, 25.-HOVER*10., 0., 1., 1., XZLAB)
!
!     don't flip this one, stretch it instead!
      call s2sch(1.5)
      call s2qtxtyzf(Y1, Y2, Z1, Z2, -13., 0., 0., 2., 0.7, YZLAB, 0.4)
      call s2sci(15)
      call s2rectyz(Y1, Y2, Z1, Z2, -13.)
      call s2sci(4)
      call s2textyzf(-13.+HOVER*5., 0., 0., 2., 0.7, YZLAB)
      call s2qtxtyzf(Y1, Y2, Z1, Z2, -13., 0., 0., 2., 0.7, YZLAB, 0.)
      call s2textyzf(-13.-HOVER*5, Y2, 0., -2., 0.7, YZLAB)
!
!     Install the callback function to plot the dynamic surface geometry
      call cs2scb(NEWCALLBACK)
!     
!     Install the callback function to handle number key presses
      call cs2sncb(NUMCB)
!     And initialise the number itself (no key pressed yet, -ve)
      NUMBER = -1
!
!     Go into S2PLOT interactive mode
      call s2show(1)
!     
      end
