! fs2uc8.f90: demonstration / use case 8 for S2PLOT library.
!
! David Barnes, February 2006
!
! $Id: fs2uc8.f,v 3.4 2007/04/04 23:07:00 dbarnes Exp $
!
! This code produces a chromastereoscopic display of points
! in a dome projection.  It's really rather cool.  You'll need
! chromastereo glasses to "maximise" the depth effect/perception.
!
!     Some useful variables
      integer NPTS
      parameter (NPTS=500)
!
      real*8 POS(3), UP(3), VDIR(3)
      real*8 NORM(3), START(3)
      real relev
      integer i
      real a(NPTS), b(NPTS)
      real dist(NPTS), size(NPTS)
!
!     open S2PLOT device
      call s2opend('/S2FISHF')
      call s2swin(-1., 1., -1., 1., -1., 1.)
!
!     set the camera position to the origin, looking at the pole
      POS(1) = 0.
      POS(2) = 0.
      POS(3) = 0.
      UP(1) = 1.
      UP(2) = 0.
      UP(3) = 0.
      VDIR(1) = 0.
      VDIR(2) = 0.
      VDIR(3) = 1.
      call ss2sc(POS, UP, VDIR, 0)
!
!     load and install the chroma colour map
      i = ss2lcm('chromapal.txt', 100, 2000)
      call s2scir(100, 100+i-1)
!
!     create a random distro of points
      DO 20 I=1,NPTS
         a(i) = RAND(0) * 360.
         b(i) = ASIN(-1. + 2. * RAND(0)) * 180. / 3.1415926
         dist(i) = SQRT(RAND(0) * 100.)
         size(i) = 11. - dist(i) * 0.8
 20   CONTINUE
!     
!     plot the points on the sky
      call s2chromapts(NPTS, a, b, dist, size, 1., 0., 10.)
!     
!     a coordinate grid
      relev = 1.1
      POS(1) = 0.
      POS(2) = 0.
      POS(3) = 0.
      NORM(1) = 0.
      NORM(2) = 0.
      NORM(3) = relev
      call s2slw(2.)
!     draw grid in blue to put in the "background"
      call s2sci(4)
!     lines of elevation
      DO 30 I=0,5
         START(1) = relev * COS(I * 15. * 3.14159 / 180.)
         START(2) = 0.
         START(3) = relev * SIN(I * 15. * 3.14159 / 180.)
         call s2vdisk(POS, NORM, START, 360., 90)
         START(3) = -START(3)
         call s2vdisk(POS, NORM, START, 360., 90)
 30   CONTINUE
!     lines of azimuth
      NORM(3) = 0.
      START(3) = 0.
      DO 40 I=0,11
         NORM(1) = -relev * COS(I * 15. * 3.14159 / 180.)
         NORM(2) = -relev * SIN(I * 15. * 3.14159 / 180.)
         START(1) = relev * COS((I * 15. + 90.) * 3.14159 / 180.)
         START(2) = relev * SIN((I * 15. + 90.) * 3.14159 / 180.)
         call s2vdisk(POS, NORM, START, 360., 45)
 40   CONTINUE

!     Go into S2PLOT interactive mode
      call s2show(1)
!     
      end
