/* s2uc1.c: demonstration / use case 1 for S2PLOT library.
 *
 * David Barnes, October 2005
 *
 * $Id: s2uc1.c,v 3.4 2006/12/22 03:33:25 dbarnes Exp $
 *
 * Demonstrates plotting points, error bars, and drawing and labelling
 * coordinate axes and labels.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "s2plot.h"

#define XLIMIT 100.0
#define YLIMIT 100.0
#define ZLIMIT 10.0
#define NPOINTS 75
#define RANDSEED 103491794l

#if defined(S2SUNOS)
#define fabsf fabs
#endif

int main(int argc, char **argv) {

  int fullscreen = 0; /* not full-screen mode */
  int stereo = 0;     /* passive stereo mode (1 for active st, 0 for mono) */

  float x1 = -XLIMIT, x2 = XLIMIT; /* x world coord range */
  float y1 = -YLIMIT, y2 = YLIMIT; /* y world coord range */
  float z1 = -ZLIMIT, z2 = ZLIMIT; /* z world coord range */
  float np = NPOINTS;              /* point population size */
  float *xpts, *ypts, *zpts;       /* point positions */
  float *expts,*eypts,*ezpts;                    /* error bar lengths */ 
  int symbol = 0;                 /* -2 = infinitesimally small dot */

  char *xopt = "BCDETSMNQ";           /* B = draw front bottom (-Y,-Z) edge 
				    * C = draw front top (-Y,+Z) edge
				    * D = draw back bottom (+Y,-Z) edge
				    * E = draw back top (+Y,+Z) edge
				    * T = draw major tick marks
				    * S = draw minor tick marks
				    */
  char *yopt = "BCDETSMNQ";           /* B = draw bottom left (-X,-Z) edge
				    * C = draw bottom right (+X,-Z) edge
				    * D = draw top left (-X,+Z) edge
				    * E = draw top right (+X,+Z) edge
				    */
  char *zopt = "BCDETSMNQ";           /* B = draw left front (-X,-Y) edge
				    * C = draw right front (+X,-Y) edge
				    * D = draw left back (-X,+Y) edge
				    * E = draw right back (+X,+Y) edge
				    */

  /* major tick increments on all axes */
  float xtick = 0.0, ytick = 0.0, ztick = 0.0;

  /* number of subdivisions on all axes */
  int nxsub = 4, nysub = 1, nzsub = 10;

  int i; /* loop variable/s */

  int interactive = 1; /* 0 = just draw; 1 = draw and go interactive */

  /* open S2PLOT device */
  if (!s2open(fullscreen, stereo, argc, argv)) {
    fprintf(stderr, "Failed to open S2PLOT device - exiting!\n");
    exit(-1);
  }

  /* set world coordinate range */
  s2swin(x1, x2, y1, y2, z1, z2);

  /* generate a set of points extending over world coordinate space */
  xpts = (float *)calloc(np, sizeof(float));
  ypts = (float *)calloc(np, sizeof(float));
  zpts = (float *)calloc(np, sizeof(float));
  expts = (float*)calloc(np, sizeof(float));
  eypts = (float*)calloc(np, sizeof(float));
  ezpts = (float*)calloc(np, sizeof(float));
  srand(RANDSEED);
  for (i = 0; i < np; i++) {
    xpts[i] = x1 + (float)(rand()) / (float)RAND_MAX * (x2 - x1);
    ypts[i] = y1 + (float)(rand()) / (float)RAND_MAX * (y2 - y1);
    zpts[i] = z1 + (float)(rand()) / (float)RAND_MAX * (z2 - z1);
    expts[i]=(float)(rand()) / (float)RAND_MAX * (x2-x1)*0.05;
    eypts[i]=fabsf(ypts[i]) * 0.1;
    ezpts[i]= (z2-z1)*0.1;
  }

  /* plot red points */
  s2sci(S2_PG_RED);
  s2pt(np, xpts, ypts, zpts, symbol);
    
  /* plot various error bars */
  s2sci(S2_PG_WHITE);
  s2errb(4, np, xpts, ypts, zpts, expts, 1);
  s2sci(S2_PG_GREEN);
  s2errb(2, np, xpts, ypts, zpts, eypts, 2);
  s2sci(S2_PG_ORANGE);
  s2errb(9, np, xpts, ypts, zpts, ezpts, 3);

  /* make a new color */
  s2scr(354, 1.0, 0.3, 0.5); /* pinkish? */

  /* draw and label a box around the points, in white */
  s2sci(354);
  s2box(xopt, xtick, nxsub, yopt, ytick, nysub, zopt, ztick, nzsub);
  s2lab("X-axis", "Y-axis", "Z-axis", "S2PLOT Demonstration 1 program");

  /* flush graphics and enter interactive mode */
  s2show(interactive);

  /* successful run */
  return 0;

}
