/* s2uc8.c: sample code 8 for S2PLOT library
 *
 * David Barnes, February 2006
 *
 * $Id: s2uc8.c,v 3.6 2007/04/04 23:07:00 dbarnes Exp $
 *
 * This code produces a chromastereoscopic display of points
 * in a dome projection.  It's really rather cool.  You'll need
 * chromastereo glasses to "maximise" the depth effect/perception.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>
#include "s2plot.h"

#define NPTS 500
#define D2R (M_PI / 180.)

#if defined(S2SUNOS)
#define asinf asin
#define sqrtf sqrt
#endif

int main(int argc, char **argv) {

  /* open S2PLOT device */
  if (!s2opend("/S2FISHF", argc, argv)) {
    fprintf(stderr, "Failed to open S2PLOT device - exiting!\n");
    exit(-1);
  }
  s2swin(-1.,1.,-1.,1.,-1.,1.);

  /* set the camera position to the origin, looking at the pole */
  // small delta in z to prevent camera coinciding with centre of geometry
  // which makes rolling difficult in some circumstances
  XYZ position = {0., 0., -0.1};
  XYZ up = {0., 1., 0.};
  XYZ vdir = {0., 0., 1.};
  ss2sc(position, up, vdir, 0);
  /* prevent translation of the camera */
  ss2tc(0);

  int i;
  float a[NPTS], b[NPTS], dist[NPTS];
  float size[NPTS];

  i = ss2lcm("chromapal.txt", 100, 2000);
  s2scir(100, 100+i-1);

  for (i = 0; i < NPTS; i++) {
    a[i] = (float)(rand()) / (float)RAND_MAX * 360.;
    b[i] = asinf(-1. + 2. * (float)(rand()) / (float)RAND_MAX) / M_PI * 180.0;
    dist[i] = sqrtf((float)(rand()) / (float)RAND_MAX * 100.);
    size[i] = 11. - dist[i] * 0.8;
  }
  s2chromapts(NPTS, a, b, dist, size, 1., 0., 10.);

  /* a coordinate grid */
  float relev = 1.1;
  XYZ posn, norm, start;
  posn.x = 0.;
  posn.y = 0.;
  posn.z = 0.;
  norm.x = 0.;
  norm.y = 0.;
  norm.z = relev;  
  s2slw(2.);
  s2sci(S2_PG_BLUE);
  /* lines of elevation */
  for (i = 0; i < 6; i++) {
    start.x = relev * cos(((float)i * 15.) * D2R);
    start.y = 0.;
    start.z = relev * sin(((float)i * 15.) * D2R);
    ns2varc(posn, norm, start, 360., 90);
    start.z = -start.z;
    ns2varc(posn, norm, start, 360., 90);
  }
  /* lines of azimuth */
  norm.z = 0.;
  start.z = 0.;
  for (i = 0; i < 12; i++) {
    norm.x = -relev * cos(((float)i * 15.) * D2R);
    norm.y = -relev * sin(((float)i * 15.) * D2R);
    start.x = relev * cos(((float)i * 15. + 90.) * D2R);
    start.y = relev * sin(((float)i * 15. + 90.) * D2R);
    ns2varc(posn, norm, start, 360., 45);
  }

  s2show(1);

  return 0;
}
